# -*- coding: utf-8 -*-
#
# test_main - tests for ubuntu_sso.main
#
# Author: Natalia Bidart <natalia.bidart@canonical.com>
# Author: Alejandro J. Cura <alecu@canonical.com>
# Author: Manuel de la Pena <manuel@canonical.com>
#
# Copyright 2009-2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Tests share by diff platforms."""

from unittest import TestCase

from mocker import MockerTestCase, MATCH

from ubuntu_sso.main import (
    CredentialsManagement,
    SSOLogin,
)


class SSOLoginMockedTestCase(MockerTestCase):
    """Test that the call are relied correctly."""

    def setUp(self):
        """Setup tests."""
        super(SSOLoginMockedTestCase, self).setUp()
        self.root = self.mocker.mock()
        mockbusname = self.mocker.mock()
        mockbus = self.mocker.mock()
        mockbusname.get_bus()
        self.mocker.result(mockbus)
        self.login = SSOLogin(mockbus)
        self.login.root = self.root
        self.mocker.reset()

    def test_generate_captcha(self):
        """Test that the call is relayed."""
        app_name = 'app'
        filename = 'file'
        self.root.generate_captcha(app_name, filename,
                                   MATCH(callable), MATCH(callable))
        self.mocker.replay()
        self.login.generate_captcha(app_name, filename)

    def test_register_user(self):
        """Test that the call is relayed."""
        app_name = 'app'
        email = 'email'
        password = 'pwd'
        name = 'display name'
        captcha_id = 'id'
        captcha_solution = 'hello'
        self.root.register_user(app_name, email, password, name, captcha_id,
                                captcha_solution,
                                MATCH(callable), MATCH(callable))
        self.mocker.replay()
        self.login.register_user(app_name, email, password, name, captcha_id,
                                 captcha_solution)

    def test_login(self):
        """Test that the call is relayed."""
        app_name = 'app'
        email = 'email'
        password = 'password'
        self.root.login(app_name, email, password,
                        MATCH(callable), MATCH(callable),
                        MATCH(callable))
        self.mocker.mock()
        self.mocker.replay()
        self.login.login(app_name, email, password)

    def test_validate_email(self):
        """Test that the call is relayed."""
        app_name = 'app'
        email = 'email'
        password = 'passwrd'
        email_token = 'token'
        self.root.validate_email(app_name, email, password, email_token,
                                 MATCH(callable),
                                 MATCH(callable))
        self.mocker.replay()
        self.login.validate_email(app_name, email, password, email_token)

    def test_request_password_reset_token(self):
        """Test that the call is relayed."""
        app_name = 'app'
        email = 'email'
        self.root.request_password_reset_token(app_name, email,
                                               MATCH(callable),
                                               MATCH(callable))
        self.mocker.replay()
        self.login.request_password_reset_token(app_name, email)

    def test_set_new_password(self):
        """Test that the call is relayed."""
        app_name = 'app'
        email = 'email'
        token = 'token'
        new_password = 'new'
        self.root.set_new_password(app_name, email, token, new_password,
                                   MATCH(callable),
                                   MATCH(callable))
        self.mocker.replay()
        self.login.set_new_password(app_name, email, token, new_password)


class CredentialsManagementMockedTestCase(MockerTestCase, TestCase):
    """Test that the call are relied correctly."""

    def setUp(self):
        """Setup tests."""
        super(CredentialsManagementMockedTestCase, self).setUp()
        self.root = self.mocker.mock()
        self.cred = CredentialsManagement(None, None)
        self.cred.root = self.root

    def test_find_credentials(self):
        """Test that the call is relayed."""
        app_name = 'app'
        args = 'args'
        self.root.find_credentials(app_name, args, MATCH(callable),
                                   MATCH(callable))
        self.mocker.replay()
        self.cred.find_credentials(app_name, args)

    def test_clear_credentials(self):
        """Test that the call is relayed."""
        app_name = 'app'
        args = 'args'
        self.root.clear_credentials(app_name, args, MATCH(callable),
                                    MATCH(callable))
        self.mocker.replay()
        self.cred.clear_credentials(app_name, args)

    def test_store_credentials(self):
        """Test that the call is relayed."""
        app_name = 'app'
        args = 'args'
        self.root.store_credentials(app_name, args, MATCH(callable),
                                    MATCH(callable))
        self.mocker.replay()
        self.cred.store_credentials(app_name, args)

    def test_register(self):
        """Test that the call is relayed."""
        app_name = 'app'
        args = 'args'
        self.root.register(app_name, args)
        self.mocker.replay()
        self.cred.register(app_name, args)

    def test_login(self):
        """Test that the call is relayed."""
        app_name = 'app'
        args = 'args'
        self.root.login(app_name, args)
        self.mocker.replay()
        self.cred.login(app_name, args)

    def test_login_email_password(self):
        """Test that the call is relayed."""
        app_name = 'app'
        args = 'args'
        self.root.login_email_password(app_name, args)
        self.mocker.replay()
        self.cred.login_email_password(app_name, args)
